function series = flatten_dbnomics_series(series)
% Adapt DBnomics series attributes to ease cell array construction.
% Rename some struct fields, remove other ones
% (the `series` struct is nested but we want a flat struct to build a cell array).

series = normalize_period(series);
series = normalize_value(series);
% Flatten dimensions.
if isfield(series, 'dimensions')
    dimensions = series.dimensions;
    fields_dim = fieldnames(dimensions);
    series = rmfield(series, {'dimensions', 'indexed_at'});
    for ii = 1:length(fields_dim)
        series.(fields_dim{ii}) = dimensions.(fields_dim{ii});
    end
end

% Flatten observation attributes.
if isfield(series, 'observation_attributes')
    observation_attributes = series.observation_attributes;
    fields_obs = fieldnames(observation_attributes);
    series = rmfield(series, 'observation_attributes');
    for ii = 1:length(fields_obs)
        series.(fields_obs{ii}) = observation_attributes.(fields_obs{ii});
    end
else
    series.observation_attributes = [];
end
end